﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using UIShell.OSGi;
using System.Xml;

namespace WebShellPlugin.ExtensionPoint
{
    public class MenuDataContainer : IDisposable
    {
        public const string MENUS_EXTENSIONPOINT = "WebShellPlugin.Menus";
        // All Menu datas.
        public List<MenuData> Menus { get; private set; }
        protected IBundle Bundle { get; private set; }
        private bool _isDisposed;

        public MenuDataContainer(IBundle bundle)
        {
            Menus = new List<MenuData>();

            Bundle = bundle;
            // Listen extension changed event.
            if (bundle.Context != null)
            {
                bundle.Context.ExtensionChanged += Context_ExtensionChanged;
            }
        }

        private void Context_ExtensionChanged(object sender, ExtensionEventArgs e)
        {
            HandleEMenusxtension();
        }

        /// <summary>
        /// Get the extensions and convert the XML nodes to MenuData list.
        /// </summary>
        private void HandleEMenusxtension()
        {
            if (Bundle.Context == null || _isDisposed)
            {
                return;
            }
            List<Extension> menuExtensions = Bundle.Context.GetExtensions(MENUS_EXTENSIONPOINT);

            Menus = new List<MenuData>();
            MenuData menu = null;
            foreach (Extension menuExtension in menuExtensions)
            {
                foreach (XmlNode dataNode in menuExtension.Data)
                {
                    if (dataNode is XmlComment)
                    {
                        continue;
                    }

                    menu = new MenuData();
                    if (dataNode.Attributes["Text"] != null)
                    {
                        menu.Text = dataNode.Attributes["Text"].Value;
                    }
                    if (dataNode.Attributes["Url"] != null)
                    {
                        menu.Url = dataNode.Attributes["Url"].Value;
                    }

                    Menus.Add(menu);
                }
            }
        }

        public void Dispose()
        {
            _isDisposed = true;
            if (Bundle.Context != null)
            {
                Bundle.Context.ExtensionChanged -= Context_ExtensionChanged;
            }
            Menus = new List<MenuData>();
        }
    }
}
